@@ -3,6 +3,7 @@ from .. import haven_utils
 from .. import haven_results as hr
 from .. import haven_utils as hu
 from .. import haven_share as hd
+from . import widgets as wdg
 
 import os
 import pprint
@@ -25,13 +26,8 @@ except:
 
 
 def plots_tab(self, output):
-    llegend_list = widgets.SelectMultiple(options=self.rm.exp_params,
-                        value=self.vars.get('legend_list', [self.rm.exp_params[0]]))
-    # widgets.Text(
-    #     value=str(self.vars.get('legend_list', '[model]')),
-    #     description='legend_list:',
-    #     disabled=False
-    # )
+    db = self
+
     llegend_format = widgets.Text(
         value=str(self.vars.get('legend_format', '')),
         description='',
@@ -56,71 +52,11 @@ def plots_tab(self, output):
         disabled=False
     )
 
-    metrics_list = [k for k in self.rm_original.score_keys if k is not 'None']
 
-    metrics_txt = widgets.Label(value="Metrics:", 
-                                layout=self.layout_label,)
-    t_y_metric =  widgets.SelectMultiple(options=metrics_list,
-                         value=self.vars.get('y_metrics', [metrics_list[0]]))
-    # t_y_metric 
 
-    # t_y_metric = widgets.Text(
-    #     value=str(self.vars.get('y_metrics', 'train_loss')),
-    #     description='y_metrics:',
-    #     disabled=False
-    # )
 
-    d_x_metric_columns = widgets.Dropdown(
-                options=metrics_list,
-                value=self.vars.get('x_metric', metrics_list[0]),
-                layout=widgets.Layout(width='300px'),
-                disabled=False,
-            )
 
-    t_groupby_list = widgets.SelectMultiple(options=['None'] + self.rm.exp_params,
-                    value=self.vars.get('groupby_list', ['None']),)
-    # widgets.Text(
-    #     value=str(self.vars.get('groupby_list')),
-    #     description='groupby_list:',
-    #     disabled=False
-    # )
-
-    t_mode = widgets.Dropdown(
-                options=['line', 'bar'],
-                value='line',
-                layout=widgets.Layout(width='300px'),
-                disabled=False,
-            )
-
-    t_bar_agg = widgets.Dropdown(
-                options=['last', 'max', 'mean'],
-                value='last',
-                layout=widgets.Layout(width='300px'),
-                disabled=False,
-            )
-
-    t_title_list = widgets.SelectMultiple(options=self.rm.exp_params,
-                    value=self.vars.get('title_list', ['dataset']),)
-    # widgets.Text(
-    #     value=str(self.vars.get('title_list', 'dataset')),
-    #     description='title_list:',
-    #     disabled=False
-    # )
-
-    d_style = widgets.Dropdown(
-        options=['False', 'True'],
-        value='False',
-        description='Interactive:',
-        layout=self.layout_dropdown,
-        disabled=False,
-    )
-
-    d_avg_across_columns = widgets.Dropdown(
-                options=['None'] + self.rm.exp_params,
-                value='None',
-                layout=widgets.Layout(width='300px'),
-                disabled=False,
-            )
+ 
 
     bdownload = widgets.Button(description="Download Plots",
                                layout=self.layout_button)
@@ -143,38 +79,67 @@ def plots_tab(self, output):
 
     bdownload.on_click(on_download_clicked)
 
-    h1 = widgets.Label(value="Y-axis Metrics:", 
-                                    layout=widgets.Layout(width='340px'),)
-    h11 = widgets.Label(value="X-axis Metric", 
-                                    layout=widgets.Layout(width='340px'),)
-    h2 = widgets.Label(value="Legend:", 
-                                    layout=widgets.Layout(width='340px'),)
+
+
     h22 = widgets.Label(value="Format:", 
                                     layout=widgets.Layout(width='340px'),)
-    h3 = widgets.Label(value="Title:", 
-                                    layout=widgets.Layout(width='340px'),)
+
     h33 = widgets.Label(value="Format:", 
                                     layout=widgets.Layout(width='340px'),)
 
-    h4 = widgets.Label(value="GroupBy:", 
-                                    layout=widgets.Layout(width='340px'),)
     h44 = widgets.Label(value="", 
                                     layout=widgets.Layout(width='340px'),)
-    h5 = widgets.Label(value="Plot Mode:", 
-                                    layout=widgets.Layout(width='320px'),)
-    h55 = widgets.Label(value="Plot Agg", 
-                                    layout=widgets.Layout(width='320px'),)
+
     space = widgets.Label(value="", 
                                     layout=widgets.Layout(width='300px'),)
     brefresh = widgets.Button(description="Display Plot")
     d_avg_across_txt = widgets.Label(value="avg_across:",)
+
+    w_y_metrics = wdg.SelectMultiple(header="Y-axis Metrics:", 
+                            options=self.rm_original.score_keys,
+                            db_vars=db.vars, 
+                            var='y_metrics')
+
+    w_legend = wdg.SelectMultiple(header="Legend:", 
+                            options=db.rm.exp_params,
+                            db_vars=db.vars, 
+                            var='legend_list')
+
+    w_title = wdg.SelectMultiple(header="Title:", 
+                            options=db.rm.exp_params,
+                            db_vars=db.vars, 
+                            var='title_list')
+
+    w_groupby = wdg.SelectMultiple(header="GroupBy:", 
+                            options=db.rm.exp_params,
+                            db_vars=db.vars, 
+                            var='groupby_list')
+
+    w_x_metric = wdg.Dropdown(header='X-axis Metric',
+                                options=self.rm_original.score_keys,
+                            db_vars=db.vars, 
+                            var='x_metric')
+    w_mode = wdg.Dropdown(header='Plot Mode',
+                                options=['line', 'bar'],
+                            db_vars=db.vars, 
+                            var='mode')
+    w_bar_agg = wdg.Dropdown(header='Plot Agg',
+                                options=['last', 'max', 'mean'],
+                            db_vars=db.vars, 
+                            var='bar_agg')
+    w_avg_across = wdg.Dropdown(header='Avg Across',
+                                options=['None'] + db.rm.exp_params,
+                            db_vars=db.vars, 
+                            var='avg_across')
+
     button = widgets.VBox([
-
-                          widgets.HBox([h1,  h2, h3, h4,  ]),
-                           widgets.HBox([t_y_metric,  llegend_list, t_title_list, t_groupby_list,]),
-
-                           widgets.HBox([h11,  h5, h55, d_avg_across_txt, ]),
-                           widgets.HBox([d_x_metric_columns,  t_mode, t_bar_agg, d_avg_across_columns,  ]),
+                    widgets.HBox([w_y_metrics.get_widget(),  w_legend.get_widget(), 
+                                 w_title.get_widget(), w_groupby.get_widget(),  ]),
+        
+                           widgets.HBox([w_x_metric.get_widget(), 
+                            w_mode.get_widget(),
+                             w_bar_agg.get_widget(),
+                            w_avg_across.get_widget(),  ]),
                         #    widgets.HBox([ d_avg_across_txt, d_avg_across_columns,  ]),
                            widgets.HBox([brefresh, bdownload, bdownload_out,]),])
 
@@ -192,58 +157,47 @@ def plots_tab(self, output):
     output_plot = widgets.Output()
 
     def on_clicked(b):
-        if d_style.value == 'True':
-            from IPython import get_ipython
-            ipython = get_ipython()
-            ipython.magic("matplotlib widget")
+        # if d_style.value == 'True':
+        #     from IPython import get_ipython
+        #     ipython = get_ipython()
+        #     ipython.magic("matplotlib widget")
         output_plot.clear_output()
         with output_plot:
             self.update_rm()
 
-            self.vars['y_metrics'] = list(t_y_metric.value)
-            self.vars['x_metric'] = d_x_metric_columns.value
 
             w, h = 10, 5
-            if len(self.vars['y_metrics']) > 1:
+            if len(w_y_metrics.update()) > 1:
                 figsize = (2*int(w), int(h))
                 self.vars['figsize'] = figsize
             else:
                 self.vars['figsize'] = (int(w), int(h))
 
-            self.vars['legend_list'] = list(llegend_list.value)
             self.vars['legend_format'] = llegend_format.value
             self.vars['log_metric_list'] = hu.get_list_from_str(
                 llog_metric_list.value)
-            self.vars['groupby_list'] = list(
-                t_groupby_list.value)
-            self.vars['mode'] = t_mode.value
-            self.vars['title_list'] = list(t_title_list.value)
-            self.vars['bar_agg'] = t_bar_agg.value
+
             self.vars['title_format'] = ltitle_format.value
             self.vars['cmap'] = lcmap.value
-            self.vars['avg_across'] = d_avg_across_columns.value
 
-            avg_across_value = self.vars['avg_across']
-            if avg_across_value == "None":
-                avg_across_value = None
 
-            self.rm_original.fig_list = self.rm.get_plot_all(y_metric_list=self.vars['y_metrics'],
-                                                             x_metric=self.vars['x_metric'],
-                                                             groupby_list=self.vars['groupby_list'],
-                                                             legend_list=self.vars['legend_list'],
+            self.rm_original.fig_list = self.rm.get_plot_all(y_metric_list=w_y_metrics.update(),
+                                                             x_metric=w_x_metric.update(),
+                                                             groupby_list=w_groupby.update(),
+                                                             legend_list=w_legend.update(),
                                                              log_metric_list=self.vars['log_metric_list'],
-                                                             mode=self.vars['mode'],
-                                                             bar_agg=self.vars['bar_agg'],
+                                                             mode=w_mode.update(),
+                                                             bar_agg=w_bar_agg.update(),
                                                              figsize=self.vars['figsize'],
-                                                             title_list=self.vars['title_list'],
+                                                             title_list=w_title.update(),
                                                              legend_format=self.vars['legend_format'],
                                                              title_format=self.vars['title_format'],
                                                              cmap=self.vars['cmap'],
-                                                             avg_across=avg_across_value)
+                                                             avg_across=w_avg_across.update())
 
             show_inline_matplotlib_plots()
 
-    d_style.observe(on_clicked)
+    # d_style.observe(on_clicked)
     brefresh.on_click(on_clicked)
 
     with output:
