@@ -3,7 +3,7 @@ import copy
 import hashlib
 import itertools
 import json
-
+import tqdm
 
 import pprint
 import os
@@ -199,6 +199,7 @@ class Parallel:
         """Constructor"""
         self.threadList = []
         self.count = 0
+        self.thread_logs = []
 
     def add(self, func,  *args):
         """Add a function to run as a process.
@@ -217,15 +218,13 @@ class Parallel:
 
     def run(self):
         """Run the added functions in parallel"""
-        for thread in self.threadList:
+        for thread in tqdm.tqdm(self.threadList, desc='Starting threads', leave=False):
             thread.daemon = True
-            print("  > Starting thread %s" % thread.name)
             thread.start()
 
     def close(self):
         """Finish: wait for all the functions to finish"""
-        for thread in self.threadList:
-            print("  > Joining thread %s" % thread.name)
+        for thread in tqdm.tqdm(self.threadList, desc='Joining threads', leave=False):
             thread.join()
 
 
@@ -246,8 +245,9 @@ def flatten_column(result_dict):
     result_dict = new_dict
     return result_dict
 
-def sort_df_columns(table):
+def sort_df_columns(table, also_first=[]):
     first = ['exp_id', 'job_state', 'job_id',  'restarts', 'started_at']
+    first += also_first
     col_list = []
     for col in first:
         if col in table.columns:
